function [ pi ] = pi_montecarlo2(n)
%PI_MONTECARLO2 Approssimazione di Pi greco con un metodo Montecarlo. 
%
% PI = PI_MONTECARLO2(N) fornisce l'approssimazione di pi greco ottenuta con
%     un metodo Montecarlo utilizzando N punti random. 

% Questa variante dello script permette di utilizzare N molto piu alti,
% evitando di allocare troppa memoria. Qui si decide un valore
% ragionevolmente massimo per la dimensione del vettore da allocare. 
maxmem = 1e6;

% Teniamo traccia del numero di tentativi fatti, e della stima di pi. 
counted = 0;
pi = 0;

while counted < n
    % Determiniamo il numero di punti da considerare
    m = min(n - counted, maxmem);
    
    % genera n punti di R2 unif distribuiti su [-1, 1] x [-1, 1]
    punti = - 1 * ones(m, 2) + 2 * rand(m, 2); 

    % Determiniamo quanti stanno all'interno del cerchio
    dentro = sum((punti(:, 1).^2+punti(:, 2).^2)<=1);
    
    pi = pi + dentro;
    counted = counted + m;
end

pi = 4 * pi / n;

end

